@@ -162,7 +162,7 @@ class OpenEphysBase(object):
 	def plotXCorrs(self):
 		if self.kilodata is None:
 			self.loadKilo()
-		from ephysiopy.ephys_generic.ephys_generic import SpikeCalcsGeneric
+		from ephysiopy.common.ephys_generic import SpikeCalcsGeneric
 		corriter = SpikeCalcsGeneric(self.kilodata.spk_times)
 		corriter.spk_clusters = self.kilodata.spk_clusters
 		corriter.plotAllXCorrs(self.kilodata.good_clusters)
@@ -186,7 +186,7 @@ class OpenEphysBase(object):
 		if jumpmax is None:
 			jumpmax = self.jumpmax
 		import matplotlib.pylab as plt
-		from ephysiopy.ephys_generic.ephys_generic import PosCalcsGeneric
+		from ephysiopy.common.ephys_generic import PosCalcsGeneric
 
 		self.__loadSettings__()
 		if self.xy is None:
@@ -237,7 +237,7 @@ class OpenEphysBase(object):
 			ppm = kwargs['ppm']
 		else:
 			ppm = 400
-		from ephysiopy.ephys_generic.ephys_generic import PosCalcsGeneric, MapCalcsGeneric
+		from ephysiopy.common.ephys_generic import PosCalcsGeneric, MapCalcsGeneric
 		if self.xy is None:
 			self.__loaddata__(**kwargs)
 		posProcessor = PosCalcsGeneric(self.xy[:,0], self.xy[:,1], ppm, jumpmax=self.jumpmax)
@@ -269,25 +269,19 @@ class OpenEphysBase(object):
 			* 'path' - just spikes on path
 			* 'both' - both of the above
 			* 'all' - both spikes on path, ratemap & SAC plotted
-
-		Notes
-		-----
-		Valid keyword arguments include:
-		* 'ppm' - this is an integer denoting pixels per metre where 
-			lower values = more bins in ratemap / SAC
+		Keyword args:
+		* 'ppm' - Integer denoting pixels per metre where lower values = more bins in ratemap / SAC
 		* 'clusters' - int or list of ints describing which clusters to plot
-			i.e. this overwrites the 'good_clusters' value in self.kilodata
-		* 'save_grid_summary_location' - bool; if present the dictionary returned from
-			gridcell.SAC.getMeasures is saved for each cluster - this is passed to MapCalcsGeneric
-
+		* 'save_grid_summary_location' - bool; if True the dictionary returned from gridcell.SAC.getMeasures is saved for each cluster
 		"""
+
 		if self.kilodata is None:
 			self.loadKilo()
 		if ( 'ppm' in kwargs.keys() ):
 			ppm = kwargs['ppm']
 		else:
 			ppm = 400
-		from ephysiopy.ephys_generic.ephys_generic import PosCalcsGeneric, MapCalcsGeneric
+		from ephysiopy.common.ephys_generic import PosCalcsGeneric, MapCalcsGeneric
 		if self.xy is None:
 			self.__loaddata__(**kwargs)
 		posProcessor = PosCalcsGeneric(self.xy[:,0], self.xy[:,1], ppm, jumpmax=self.jumpmax)
@@ -323,7 +317,7 @@ class OpenEphysBase(object):
 		-----
 		EEGCalcsGeneric.plotPowerSpectrum
 		"""
-		from ephysiopy.ephys_generic.ephys_generic import EEGCalcsGeneric
+		from ephysiopy.common.ephys_generic import EEGCalcsGeneric
 		if self.rawData is None:
 			print("Loading raw data...")
 			self.load(loadraw=True)
@@ -334,7 +328,7 @@ class OpenEphysBase(object):
 		E.plotPowerSpectrum()
 
 	def plotSpectrogram(self, nSeconds=30, secsPerBin=2, ax=None, ymin=0, ymax=250):
-		from ephysiopy.ephys_generic.ephys_generic import EEGCalcsGeneric
+		from ephysiopy.common.ephys_generic import EEGCalcsGeneric
 		if self.rawData is None:
 			print("Loading raw data...")
 			self.load(loadraw=True)
@@ -345,7 +339,7 @@ class OpenEphysBase(object):
 		from scipy import signal
 		freqs, times, Sxx = signal.spectrogram(E.sig, fs, nperseg=nperseg)
 		Sxx_sm = Sxx
-		from ephysiopy.ephys_generic import binning
+		from ephysiopy.common import binning
 		R = binning.RateMap()
 		Sxx_sm = R.blurImage(Sxx, (secsPerBin*2)+1)
 		x, y = np.meshgrid(times, freqs)
@@ -366,7 +360,7 @@ class OpenEphysBase(object):
 		self.settings.parseStimControl()
 		if self.kilodata is None:
 			self.loadKilo()
-		from ephysiopy.ephys_generic.ephys_generic import SpikeCalcsGeneric
+		from ephysiopy.common.ephys_generic import SpikeCalcsGeneric
 		spk_times = (self.kilodata.spk_times.T[0] / 3e4) + self.ts[0] # in seconds
 		S = SpikeCalcsGeneric(spk_times)
 		S.event_ts = self.ttl_timestamps[2::2] # this is because some of the trials have two weird events logged at about 2-3 minutes in...
@@ -376,7 +370,7 @@ class OpenEphysBase(object):
 			print(next(S.plotPSTH(x)))
 
 	def plotEventEEG(self):
-		from ephysiopy.ephys_generic.ephys_generic import EEGCalcsGeneric
+		from ephysiopy.common.ephys_generic import EEGCalcsGeneric
 		if self.rawData is None:
 			print("Loading raw data...")
 			self.load(loadraw=True)
@@ -414,7 +408,7 @@ class OpenEphysNPX(OpenEphysBase):
 		self.path2LFPdata = None
 
 	def load(self, pname_root=None, experiment_name='experiment1', recording_name='recording1'):
-		'''
+		"""
 		Loads data recorded in the OE 'flat' binary format
 		See https://open-ephys.atlassian.net/wiki/spaces/OEW/pages/166789121/Flat+binary+format for more
 
@@ -423,7 +417,7 @@ class OpenEphysNPX(OpenEphysBase):
 		pname_root - str - the top level directory, typically in form of YYYY-MM-DD_HH-MM-SS
 
 		recording_name - str - pretty obvious but this is also the directory immediately beneath pname_root
-		'''
+		"""
 		self.isBinary = True
 		import os
 		import re
@@ -513,7 +507,7 @@ class OpenEphysNPX(OpenEphysBase):
 		channel_map = np.squeeze(np.load(os.path.join(self.path2APdata, 'channel_map.npy')))
 		lfp_sample_rate = 2500
 		data = np.array(mmap[channel_map, 0:nseconds*lfp_sample_rate])
-		from ephysiopy.ephys_generic.ephys_generic import EEGCalcsGeneric
+		from ephysiopy.common.ephys_generic import EEGCalcsGeneric
 		E = EEGCalcsGeneric(data[0, :], lfp_sample_rate)
 		E.calcEEGPowerSpectrum()
 		spec_data = np.zeros(shape=(data.shape[0], len(E.sm_power[0::50])))
@@ -575,7 +569,7 @@ class OpenEphysNPX(OpenEphysBase):
 		super().plotEEGPower(channel)
 
 	def plotSpectrogram(self, nSeconds=30, secsPerBin=2, ax=None, ymin=0, ymax=250):
-		super().plotSpectrogram(self, nSeconds, secsPerBin, ax, ymin, ymax)
+		super().plotSpectrogram(nSeconds, secsPerBin, ax, ymin, ymax)
 
 	def plotPSTH(self):
 		super().plotPSTH()
@@ -774,13 +768,13 @@ class SpkTimeCorrelogram(object):
 			yield cluster
 
 class SpkWaveform(object):
-	'''
+	"""
 
-	'''
+	"""
 	def __init__(self, clusters, spk_times, spk_clusters, amplitudes, raw_data):
-		'''
+		"""
 		spk_times in samples
-		'''
+		"""
 		self.clusters = clusters
 		self.spk_times = spk_times
 		self.spk_clusters = spk_clusters
